@@ -1,10 +1,9 @@
 #pragma once
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
-
 #include <pthread.h>
+#ifdef __FreeBSD__
+#include <pthread_np.h>
+#endif
 #include <sched.h>
 
 #include <set>
@@ -22,7 +21,7 @@ public:
 
 public:
   static int count();
-  static int getaffinity(const pthread_t thread_id, cpu_set_t *cpuset);
+  static int getaffinity(cpu_set_t *cpuset);
   static int setaffinity(const pthread_t thread_id, cpu_set_t *cpuset);
   static int setaffinity(const pthread_t thread_id, const int cpu);
   static int setaffinity(const pthread_t thread_id, const std::set<int> cpus);
