@@ -20,6 +20,8 @@
 
 #include "fmp.h"
 
+#include "mutex.hpp"
+
 #include <pthread.h>
 
 
@@ -39,7 +41,7 @@ lfmp_init(lfmp_t         *lfmp_,
           const uint64_t  page_multiple_)
 {
   fmp_init(&lfmp_->fmp,obj_size_,page_multiple_);
-  pthread_mutex_init(&lfmp_->lock,NULL);
+  mutex_init(&lfmp_->lock);
 }
 
 static
@@ -47,7 +49,7 @@ inline
 void
 lfmp_lock(lfmp_t *lfmp_)
 {
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
 }
 
 static
@@ -55,7 +57,7 @@ inline
 void
 lfmp_unlock(lfmp_t *lfmp_)
 {
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 }
 
 static
@@ -65,9 +67,9 @@ lfmp_slab_count(lfmp_t *lfmp_)
 {
   uint64_t rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_slab_count(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -79,9 +81,9 @@ lfmp_slab_alloc(lfmp_t *lfmp_)
 {
   int rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_slab_alloc(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -93,9 +95,9 @@ lfmp_alloc(lfmp_t *lfmp_)
 {
   void *rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_alloc(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -107,9 +109,9 @@ lfmp_calloc(lfmp_t *lfmp_)
 {
   void *rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_calloc(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -120,9 +122,9 @@ void
 lfmp_free(lfmp_t *lfmp_,
           void   *obj_)
 {
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   fmp_free(&lfmp_->fmp,obj_);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 }
 
 static
@@ -130,9 +132,9 @@ inline
 void
 lfmp_clear(lfmp_t *lfmp_)
 {
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   fmp_clear(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 }
 
 static
@@ -140,10 +142,10 @@ inline
 void
 lfmp_destroy(lfmp_t *lfmp_)
 {
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   fmp_destroy(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
-  pthread_mutex_destroy(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
+  mutex_destroy(&lfmp_->lock);
 }
 
 static
@@ -153,9 +155,9 @@ lfmp_avail_objs(lfmp_t *lfmp_)
 {
   uint64_t rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_avail_objs(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -168,9 +170,9 @@ lfmp_objs_in_slab(lfmp_t *lfmp_,
 {
   uint64_t rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_objs_in_slab(&lfmp_->fmp,slab_);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -181,9 +183,9 @@ void
 lfmp_remove_objs_in_slab(lfmp_t *lfmp_,
                          void   *slab_)
 {
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   fmp_remove_objs_in_slab(&lfmp_->fmp,slab_);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 }
 
 static
@@ -193,9 +195,9 @@ lfmp_gc(lfmp_t *lfmp_)
 {
   int rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_gc(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -207,9 +209,9 @@ lfmp_objs_per_slab(lfmp_t *lfmp_)
 {
   uint64_t rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_objs_per_slab(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -221,9 +223,9 @@ lfmp_slab_usage_ratio(lfmp_t *lfmp_)
 {
   double rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_slab_usage_ratio(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
@@ -235,9 +237,9 @@ lfmp_total_allocated_memory(lfmp_t *lfmp_)
 {
   uint64_t rv;
 
-  pthread_mutex_lock(&lfmp_->lock);
+  mutex_lock(&lfmp_->lock);
   rv = fmp_total_allocated_memory(&lfmp_->fmp);
-  pthread_mutex_unlock(&lfmp_->lock);
+  mutex_unlock(&lfmp_->lock);
 
   return rv;
 }
