@@ -23,21 +23,18 @@
 #include "fs_glob.hpp"
 #include "fs_is_rofs.hpp"
 #include "fs_realpathize.hpp"
-#include "nonstd/optional.hpp"
+#include "int_types.h"
 #include "num.hpp"
 #include "str.hpp"
 #include "syslog.hpp"
 
 #include <string>
+#include <optional>
 
 #include <fnmatch.h>
 
-using std::string;
-using std::vector;
-using nonstd::optional;
 
-
-Branches::Impl::Impl(const uint64_t &default_minfreespace_)
+Branches::Impl::Impl(const u64 &default_minfreespace_)
   : _default_minfreespace(default_minfreespace_)
 {
 }
@@ -45,8 +42,9 @@ Branches::Impl::Impl(const uint64_t &default_minfreespace_)
 Branches::Impl&
 Branches::Impl::operator=(Branches::Impl &rval_)
 {
-  auto this_base = dynamic_cast<Branch::Vector*>(this);
-  auto rval_base = dynamic_cast<Branch::Vector*>(&rval_);
+  using type = std::vector<Branch>;
+  auto this_base = dynamic_cast<type*>(this);
+  auto rval_base = dynamic_cast<type*>(&rval_);
 
   *this_base = *rval_base;
 
@@ -56,8 +54,9 @@ Branches::Impl::operator=(Branches::Impl &rval_)
 Branches::Impl&
 Branches::Impl::operator=(Branches::Impl &&rval_)
 {
-  auto this_base = dynamic_cast<Branch::Vector*>(this);
-  auto rval_base = dynamic_cast<Branch::Vector*>(&rval_);
+  using type = std::vector<Branch>;
+  auto this_base = dynamic_cast<type*>(this);
+  auto rval_base = dynamic_cast<type*>(&rval_);
 
   *this_base = std::move(*rval_base);
 
@@ -65,7 +64,7 @@ Branches::Impl::operator=(Branches::Impl &&rval_)
 }
 
 const
-uint64_t&
+u64&
 Branches::Impl::minfreespace(void) const
 {
   return _default_minfreespace;
@@ -75,16 +74,15 @@ namespace l
 {
   static
   void
-  split(const std::string &s_,
-        std::string       *instr_,
-        std::string       *values_)
+  split(const std::string_view  s_,
+        std::string            *instr_,
+        std::string            *values_)
   {
-    uint64_t offset;
+    u64 offset;
 
     offset = s_.find_first_not_of("+<>-=");
-    if (offset == std::string::npos) {
+    if(offset == std::string::npos)
       return;
-    }
 
     if(offset > 1)
       offset = 2;
@@ -94,8 +92,8 @@ namespace l
 
   static
   int
-  parse_mode(const string &str_,
-             Branch::Mode *mode_)
+  parse_mode(const std::string &str_,
+             Branch::Mode      *mode_)
   {
     if(str_ == "RW")
       *mode_ = Branch::Mode::RW;
@@ -111,11 +109,11 @@ namespace l
 
   static
   int
-  parse_minfreespace(const string       &str_,
-                     optional<uint64_t> *minfreespace_)
+  parse_minfreespace(const std::string  &str_,
+                     std::optional<u64> *minfreespace_)
   {
     int rv;
-    uint64_t uint64;
+    u64 uint64;
 
     rv = str::from(str_,&uint64);
     if(rv < 0)
@@ -128,14 +126,14 @@ namespace l
 
   static
   int
-  parse_branch(const string       &str_,
-               string             *glob_,
+  parse_branch(const std::string  &str_,
+               std::string        *glob_,
                Branch::Mode       *mode_,
-               optional<uint64_t> *minfreespace_)
+               std::optional<u64> *minfreespace_)
   {
     int rv;
-    string options;
-    vector<string> v;
+    std::string options;
+    std::vector<std::string> v;
 
     str::rsplit1(str_,'=',&v);
     switch(v.size())
@@ -155,6 +153,7 @@ namespace l
             rv = l::parse_minfreespace(v[1],minfreespace_);
             if(rv < 0)
               return rv;
+            [[fallthrough]];
           case 1:
             rv = l::parse_mode(v[0],mode_);
             if(rv < 0)
@@ -173,31 +172,49 @@ namespace l
 
   static
   int
-  parse(const string   &str_,
-        Branches::Impl *branches_)
+  parse(const std::string &str_,
+        Branches::Impl    *branches_)
   {
     int rv;
-    string glob;
+    std::string glob;
     StrVec paths;
-    optional<uint64_t> minfreespace;
-    Branch branch(branches_->minfreespace());
+    Branch branch;
+    std::optional<u64> minfreespace;
+
+    branch._minfreespace = &branches_->minfreespace();
 
     rv = l::parse_branch(str_,&glob,&branch.mode,&minfreespace);
     if(rv < 0)
       return rv;
 
     if(minfreespace.has_value())
-      branch.set_minfreespace(minfreespace.value());
+      branch._minfreespace = minfreespace.value();
 
     fs::glob(glob,&paths);
     if(paths.empty())
-      paths.push_back(glob);
+      {
+        SysLog::notice("branch glob `{}` found no matches,"
+                       " adding the literal to branches",glob);
+        paths.push_back(glob);
+      }
 
     fs::realpathize(&paths);
     for(auto &path : paths)
       {
+        std::error_code ec;
+
+        if(!std::filesystem::exists(path))
+          {
+            SysLog::notice("branch `{}` does not currently exist",path);
+          }
+        else if(!std::filesystem::is_directory(path,ec))
+          {
+            SysLog::warning("branch `{}` is not a directory, skipping",path);
+            continue;
+          }
+
         branch.path = path;
-        branches_->push_back(branch);
+        branches_->emplace_back(branch);
       }
 
     return 0;
@@ -205,8 +222,8 @@ namespace l
 
   static
   int
-  set(const std::string &str_,
-      Branches::Impl    *branches_)
+  set(const std::string_view  str_,
+      Branches::Impl         *branches_)
   {
     int rv;
     StrVec paths;
@@ -227,11 +244,11 @@ namespace l
 
   static
   int
-  add_begin(const std::string &str_,
-            Branches::Impl    *branches_)
+  add_begin(const std::string_view  str_,
+            Branches::Impl         *branches_)
   {
     int rv;
-    vector<string> paths;
+    std::vector<std::string> paths;
     Branches::Impl tmp_branches(branches_->minfreespace());
 
     str::split(str_,':',&paths);
@@ -251,8 +268,8 @@ namespace l
 
   static
   int
-  add_end(const std::string &str_,
-          Branches::Impl    *branches_)
+  add_end(const std::string_view  str_,
+          Branches::Impl         *branches_)
   {
     int rv;
     StrVec paths;
@@ -293,8 +310,8 @@ namespace l
 
   static
   int
-  erase_fnmatch(const std::string &str_,
-                Branches::Impl    *branches_)
+  erase_fnmatch(const std::string_view  str_,
+                Branches::Impl         *branches_)
   {
     StrVec patterns;
 
@@ -302,10 +319,13 @@ namespace l
     for(auto i = branches_->begin(); i != branches_->end();)
       {
         int match = FNM_NOMATCH;
+        Branch &branch = *i;
 
         for(auto pi = patterns.cbegin(); pi != patterns.cend() && match != 0; ++pi)
           {
-            match = ::fnmatch(pi->c_str(),i->path.c_str(),0);
+            match = ::fnmatch(pi->c_str(),
+                              branch.path.c_str(),
+                              0);
           }
 
         i = ((match == 0) ? branches_->erase(i) : (i+1));
@@ -316,7 +336,7 @@ namespace l
 }
 
 int
-Branches::Impl::from_string(const std::string &s_)
+Branches::Impl::from_string(const std::string_view s_)
 {
   std::string instr;
   std::string values;
@@ -346,7 +366,7 @@ Branches::Impl::from_string(const std::string &s_)
 std::string
 Branches::Impl::to_string(void) const
 {
-  string tmp;
+  std::string tmp;
 
   if(empty())
     return tmp;
@@ -371,10 +391,10 @@ Branches::Impl::to_paths(StrVec &paths_) const
     }
 }
 
-fs::PathVector
+std::vector<fs::path>
 Branches::Impl::to_paths() const
 {
-  fs::PathVector vp;
+  std::vector<fs::path> vp;
 
   for(const auto &branch : *this)
     vp.emplace_back(branch.path);
@@ -383,7 +403,7 @@ Branches::Impl::to_paths() const
 }
 
 int
-Branches::from_string(const std::string &str_)
+Branches::from_string(const std::string_view str_)
 {
   int rv;
   Branches::Ptr impl;
@@ -409,7 +429,7 @@ Branches::from_string(const std::string &str_)
   return 0;
 }
 
-string
+std::string
 Branches::to_string(void) const
 {
   std::lock_guard<std::mutex> lock_guard(_mutex);
@@ -428,8 +448,8 @@ Branches::find_and_set_mode_ro()
       if(!fs::is_rofs_but_not_mounted_ro(branch.path))
         continue;
 
-      syslog_warning("Branch %s found to be readonly - setting its mode to RO",
-                     branch.path.c_str());
+      SysLog::warning("branch `{}` found to be readonly - setting its mode=RO",
+                      branch.path.string());
 
       branch.mode = Branch::Mode::RO;
     }
@@ -442,7 +462,7 @@ SrcMounts::SrcMounts(Branches &b_)
 }
 
 int
-SrcMounts::from_string(const std::string &s_)
+SrcMounts::from_string(const std::string_view s_)
 {
   //  return _branches.from_string(s_);
   return 0;
@@ -452,7 +472,7 @@ std::string
 SrcMounts::to_string(void) const
 {
   std::string rv;
-  Branches::CPtr branches = _branches;
+  Branches::Ptr branches = _branches;
 
   if(branches->empty())
     return rv;
