@@ -19,7 +19,7 @@
 #pragma once
 
 #include "branch.hpp"
-#include "fs_pathvector.hpp"
+#include "fs_path.hpp"
 #include "strvec.hpp"
 #include "tofrom_string.hpp"
 
@@ -28,69 +28,83 @@
 #include <mutex>
 #include <string>
 #include <vector>
+#include <memory>
+
+#define MINFREESPACE_DEFAULT (4294967295ULL)
 
 
 class Branches final : public ToFromString
 {
 public:
-  class Impl final : public ToFromString, public Branch::Vector
+  class Impl final : public ToFromString,
+                     public std::vector<Branch>
   {
-  public:
-    typedef std::shared_ptr<Impl> Ptr;
-    typedef std::shared_ptr<const Impl> CPtr;
+  private:
+    const u64 &_default_minfreespace;
 
   public:
-    Impl(const uint64_t &default_minfreespace_);
+    using Ptr  = std::shared_ptr<Impl>;
 
   public:
-    int from_string(const std::string &str) final;
+    Impl(const u64 &default_minfreespace);
+
+  public:
+    int from_string(const std::string_view str) final;
     std::string to_string(void) const final;
 
   public:
-    const uint64_t& minfreespace(void) const;
+    const u64 &minfreespace(void) const;
     void to_paths(StrVec &strvec) const;
-    fs::PathVector to_paths() const;
+    std::vector<fs::path> to_paths() const;
 
   public:
     Impl& operator=(Impl &impl_);
     Impl& operator=(Impl &&impl_);
-
-  private:
-    const uint64_t &_default_minfreespace;
   };
 
-public:
-  typedef Branches::Impl::Ptr  Ptr;
-  typedef Branches::Impl::CPtr CPtr;
 
 public:
-  Branches(const uint64_t &default_minfreespace_)
-    : _impl(std::make_shared<Impl>(default_minfreespace_))
-  {}
+  using Ptr = Branches::Impl::Ptr;
 
 public:
-  int from_string(const std::string &str) final;
-  std::string to_string(void) const final;
-
-public:
-  operator CPtr()   const { std::lock_guard<std::mutex> lg(_mutex); return _impl; }
-  CPtr operator->() const { std::lock_guard<std::mutex> lg(_mutex); return _impl; }
-
-public:
-  void find_and_set_mode_ro();
+  u64 minfreespace = MINFREESPACE_DEFAULT;
 
 private:
   mutable std::mutex _mutex;
   Ptr                _impl;
+
+public:
+  Branches()
+    : _impl(std::make_shared<Impl>(minfreespace))
+  {
+  }
+
+public:
+  int from_string(const std::string_view str) final;
+  std::string to_string(void) const final;
+
+public:
+  operator Ptr()   const { std::lock_guard<std::mutex> lg(_mutex); return _impl; }
+  Ptr operator->() const { std::lock_guard<std::mutex> lg(_mutex); return _impl; }
+
+public:
+  Impl::iterator begin() { return _impl->begin(); }
+  Impl::iterator end() { return _impl->end(); }
+  Impl::const_iterator begin() const { return _impl->begin(); }
+  Impl::const_iterator end() const { return _impl->end(); }
+
+
+public:
+  void find_and_set_mode_ro();
 };
 
 class SrcMounts : public ToFromString
 {
 public:
-  SrcMounts(Branches &b_);
+  SrcMounts(Branches &b);
 
 public:
-  int from_string(const std::string &str) final;
+  int from_string(const std::string_view str) final;
   std::string to_string(void) const final;
 
 private:
