@@ -27,7 +27,7 @@ namespace Category
   class Base : public ToFromString
   {
   public:
-    int from_string(const std::string &s) final;
+    int from_string(const std::string_view s) final;
     std::string to_string() const final;
 
   protected:
