@@ -19,14 +19,20 @@
 #include "branches.hpp"
 #include "category.hpp"
 #include "config_cachefiles.hpp"
+#include "config_dummy.hpp"
 #include "config_flushonclose.hpp"
 #include "config_follow_symlinks.hpp"
-#include "config_pid.hpp"
+#include "config_gidcache.hpp"
 #include "config_inodecalc.hpp"
 #include "config_link_exdev.hpp"
 #include "config_log_metrics.hpp"
 #include "config_moveonenospc.hpp"
 #include "config_nfsopenhack.hpp"
+#include "config_noforget.hpp"
+#include "config_pagesize.hpp"
+#include "config_passthrough_io.hpp"
+#include "config_pid.hpp"
+#include "config_proxy_ioprio.hpp"
 #include "config_rename_exdev.hpp"
 #include "config_set.hpp"
 #include "config_statfs.hpp"
@@ -34,11 +40,15 @@
 #include "config_xattr.hpp"
 #include "enum.hpp"
 #include "errno.hpp"
+#include "fs_path.hpp"
 #include "funcs.hpp"
+#include "fuse_cfg.hpp"
 #include "fuse_readdir.hpp"
 #include "policy.hpp"
 #include "rwlock.hpp"
+#include "tofrom_ref.hpp"
 #include "tofrom_wrapper.hpp"
+#include "syslog.hpp"
 
 #include "fuse.h"
 
@@ -52,9 +62,12 @@
 
 typedef ToFromWrapper<bool>                 ConfigBOOL;
 typedef ToFromWrapper<uint64_t>             ConfigUINT64;
+typedef ToFromWrapper<int64_t>              ConfigS64;
 typedef ToFromWrapper<int>                  ConfigINT;
 typedef ToFromWrapper<std::string>          ConfigSTR;
+typedef ToFromWrapper<fs::path>             ConfigPath;
 typedef std::map<std::string,ToFromString*> Str2TFStrMap;
+typedef ROToFromWrapper<std::string>        ConfigROSTR;
 
 extern const std::string CONTROLFILE;
 
@@ -65,34 +78,28 @@ public:
   {
     int err;
     std::string str;
+
+    std::string to_string() const;
   };
 
   typedef std::vector<Err> ErrVec;
 
 public:
-  class Read
-  {
-  public:
-    Read();
-
-  public:
-    inline const Config* operator->() const;
-
-  private:
-    const Config &_cfg;
-  };
+  ErrVec errs;
 
 public:
-  class Write
+  class CfgConfigFile : public ToFromString
   {
-  public:
-    Write();
-
-  public:
-    Config* operator->();
-
   private:
-    Config &_cfg;
+    fs::path  _cfg_file;
+    int       _depth = 0;
+
+  public:
+    CfgConfigFile();
+
+  public:
+    int from_string(const std::string_view s_) final;
+    std::string to_string(void) const final;
   };
 
 public:
@@ -102,11 +109,11 @@ public:
   Config& operator=(const Config&);
 
 public:
+  ConfigBOOL     allow_idmap;
   ConfigBOOL     async_read;
-  ConfigBOOL     auto_cache;
-  ConfigUINT64   minfreespace;
   Branches       branches;
   ConfigUINT64   branches_mount_timeout;
+  ConfigBOOL     branches_mount_timeout_fail;
   ConfigUINT64   cache_attr;
   ConfigUINT64   cache_entry;
   CacheFiles     cache_files;
@@ -115,48 +122,72 @@ public:
   ConfigBOOL     cache_readdir;
   ConfigUINT64   cache_statfs;
   ConfigBOOL     cache_symlinks;
+  ConfigBOOL     cache_writeback;
   Categories     category;
-  ConfigBOOL     direct_io;
+  CfgConfigFile  config_file;
+  ConfigBOOL     direct_io_allow_mmap;
   ConfigBOOL     dropcacheonclose;
   ConfigBOOL     export_support;
   FlushOnClose   flushonclose;
   FollowSymlinks follow_symlinks;
   ConfigSTR      fsname;
   Funcs          func;
-  ConfigUINT64   fuse_msg_size;
+  ConfigPageSize fuse_msg_size;
+  GIDCacheExpireTimeout gid_cache_expire_timeout;
+  GIDCacheRemoveTimeout gid_cache_remove_timeout;
+  ConfigBOOL     handle_killpriv;
+  ConfigBOOL     handle_killpriv_v2;
   ConfigBOOL     ignorepponrename;
   InodeCalc      inodecalc;
-  ConfigBOOL     kernel_cache;
+  ConfigBOOL     kernel_permissions_check;
   ConfigBOOL     lazy_umount_mountpoint;
   ConfigBOOL     link_cow;
   LinkEXDEV      link_exdev;
   LogMetrics     log_metrics;
-  ConfigSTR      mountpoint;
+  TFSRef<u64>    minfreespace;
+  fs::path       mountpoint;
   MoveOnENOSPC   moveonenospc;
   NFSOpenHack    nfsopenhack;
   ConfigBOOL     nullrw;
   ConfigBOOL     parallel_direct_writes;
+  PassthroughIO  passthrough_io;
+  TFSRef<int>    passthrough_max_stack_depth;
   ConfigGetPid   pid;
+  TFSRef<std::string> pin_threads;
   ConfigBOOL     posix_acl;
+  TFSRef<int>    process_thread_count;
+  TFSRef<int>    process_thread_queue_depth;
+  ProxyIOPrio    proxy_ioprio;
+  TFSRef<int>    read_thread_count;
   ConfigUINT64   readahead;
   FUSE::ReadDir  readdir;
-  ConfigBOOL     readdirplus;
   RenameEXDEV    rename_exdev;
   ConfigINT      scheduling_priority;
   ConfigBOOL     security_capability;
-  SrcMounts      srcmounts;
   StatFS         statfs;
   StatFSIgnore   statfs_ignore;
   ConfigBOOL     symlinkify;
-  ConfigUINT64   symlinkify_timeout;
-  ConfigINT      fuse_read_thread_count;
-  ConfigINT      fuse_process_thread_count;
-  ConfigINT      fuse_process_thread_queue_depth;
-  ConfigSTR      fuse_pin_threads;
-  ConfigSTR      version;
-  ConfigBOOL     writeback_cache;
+  ConfigS64      symlinkify_timeout;
   XAttr          xattr;
 
+private:
+  TFSRef<int>      _congestion_threshold;
+  TFSRef<bool>     _debug;
+  CfgDummy         _dummy;
+  TFSRef<s64>      _gid;
+  TFSRef<int>      _max_background;
+  TFSRef<fs::path> _mount;
+  TFSRef<fs::path> _mountpoint;
+  CfgNoforget      _never_forget_nodes;
+  CfgNoforget      _noforget;
+  TFSRef<s64>      _remember;
+  TFSRef<s64>      _remember_nodes;
+  SrcMounts        _srcmounts;
+  TFSRef<int>      _threads;
+  TFSRef<s64>      _uid;
+  TFSRef<s64>      _umask;
+  ConfigROSTR      _version;
+
 private:
   bool _initialized;
 
@@ -171,55 +202,30 @@ public:
   bool has_key(const std::string &key) const;
   void keys(std::string &s) const;
   void keys_xattr(std::string &s) const;
+  ssize_t keys_listxattr(char *list, size_t size) const;
+  ssize_t keys_listxattr_size() const;
 
 public:
   int get(const std::string &key, std::string *val) const;
-  int set_raw(const std::string &key, const std::string &val);
   int set(const std::string &key, const std::string &val);
   int set(const std::string &kv);
 
 public:
-  int from_stream(std::istream &istrm, ErrVec *errs);
-  int from_file(const std::string &filepath, ErrVec *errs);
+  int from_stream(std::istream &istrm);
+  int from_file(const std::string &filepath);
+
+public:
+  static bool is_rootdir(const fs::path &fusepath);
+  static bool is_ctrl_file(const fs::path &fusepath);
+  static bool is_mergerfs_xattr(const char *attrname);
+  static bool is_cmd_xattr(const std::string_view &attrname);
+  static std::string prune_ctrl_xattr(const std::string &s);
+  static std::string_view prune_cmd_xattr(const std::string_view &s);
 
 private:
   Str2TFStrMap _map;
-
-private:
-  static Config _singleton;
-
-public:
-  friend class Read;
-  friend class Write;
 };
 
 std::ostream& operator<<(std::ostream &s,const Config::ErrVec &ev);
 
-inline
-Config::Read::Read()
-  : _cfg(Config::_singleton)
-{
-
-}
-
-inline
-const
-Config*
-Config::Read::operator->() const
-{
-  return &_cfg;
-}
-
-inline
-Config::Write::Write()
-  : _cfg(Config::_singleton)
-{
-
-}
-
-inline
-Config*
-Config::Write::operator->()
-{
-  return &_cfg;
-}
+extern Config cfg;
