@@ -30,12 +30,12 @@ class MoveOnENOSPC : public ToFromString
 public:
   MoveOnENOSPC(const bool enabled_)
     : enabled(enabled_),
-      policy(&Policies::Create::mfs)
+      policy(&Policies::Create::pfrd)
   {
   }
 
 public:
-  int from_string(const std::string &s) final;
+  int from_string(const std::string_view s) final;
   std::string to_string() const final;
 
 public:
