@@ -31,5 +31,5 @@ public:
 
 public:
   std::string to_string(void) const final;
-  int from_string(const std::string &) final;
+  int from_string(const std::string_view) final;
 };
