@@ -18,14 +18,34 @@
 
 #include "fh.hpp"
 
-#include <string>
+#include "int_types.h"
 
 
 class DirInfo : public FH
 {
 public:
-  DirInfo(const char *fusepath_)
+  static DirInfo *from_fh(const u64 fh);
+
+public:
+  u64 to_fh() const;
+
+public:
+  DirInfo(const fs::path &fusepath_)
     : FH(fusepath_)
   {
   }
 };
+
+inline
+uint64_t
+DirInfo::to_fh() const
+{
+  return reinterpret_cast<u64>(this);
+}
+
+inline
+DirInfo*
+DirInfo::from_fh(const u64 fh_)
+{
+  return reinterpret_cast<DirInfo*>(fh_);
+}
