@@ -30,11 +30,11 @@ public:
   typedef E ENUM;
 
 public:
-  Enum<ENUM>()
+  Enum()
   {
   }
 
-  Enum<ENUM>(const ENUM data_)
+  Enum(const ENUM data_)
     : _data(data_)
   {
   }
@@ -68,7 +68,7 @@ public:
 
 public:
   std::string to_string() const final;
-  int from_string(const std::string &) final;
+  int from_string(const std::string_view) final;
 
 public:
   int to_int() const
