@@ -16,27 +16,71 @@
 
 #pragma once
 
+#include "branch.hpp"
 #include "fh.hpp"
+#include "fs_path.hpp"
 
-#include <cstdint>
-#include <string>
 #include <mutex>
 
+#include "int_types.h"
+
 
 class FileInfo : public FH
 {
 public:
-  FileInfo(int const   fd_,
-           char const *fusepath_,
-           bool const  direct_io_)
+  static FileInfo *from_fh(const u64 fh);
+
+public:
+  FileInfo(const int       fd_,
+           const Branch   *branch_,
+           const fs::path &fusepath_,
+           const bool      direct_io_)
     : FH(fusepath_),
       fd(fd_),
+      branch(*branch_),
       direct_io(direct_io_)
   {
   }
 
+  FileInfo(const int       fd_,
+           const Branch   &branch_,
+           const fs::path &fusepath_,
+           const bool      direct_io_)
+    : FH(fusepath_),
+      fd(fd_),
+      branch(branch_),
+      direct_io(direct_io_)
+  {
+  }
+
+  FileInfo(const FileInfo *fi_)
+    : FH(fi_->fusepath),
+      fd(fi_->fd),
+      branch(fi_->branch),
+      direct_io(fi_->direct_io)
+  {
+  }
+
+public:
+  u64 to_fh() const;
+
 public:
   int fd;
-  uint32_t direct_io:1;
+  Branch branch;
+  u32 direct_io:1;
   std::mutex mutex;
 };
+
+inline
+u64
+FileInfo::to_fh() const
+{
+  return reinterpret_cast<u64>(this);
+}
+
+inline
+FileInfo*
+FileInfo::from_fh(const u64 fh_)
+{
+  return reinterpret_cast<FileInfo*>(fh_);
+}
