@@ -18,15 +18,20 @@
 
 #pragma once
 
+#include "fs_path.hpp"
+
 #include <cstdint>
 #include <string>
+#include <string_view>
 
 
 namespace str
 {
-  int from(const std::string &, bool *);
-  int from(const std::string &, int *);
-  int from(const std::string &, uint64_t *);
-  int from(const std::string &, std::string *);
-  int from(const std::string &, const std::string *);
+  int from(const std::string_view, bool *);
+  int from(const std::string_view, int *);
+  int from(const std::string_view, uint64_t *);
+  int from(const std::string_view, int64_t *);
+  int from(const std::string_view, std::string *);
+  int from(const std::string_view, const std::string *);
+  int from(const std::string_view, fs::path *);
 }
