@@ -16,10 +16,12 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "fs_copy_file_range.hpp"
+
 #ifdef __linux__
-#warning "using fs_copy_file_range_linux.icpp"
+#pragma message "using fs_copy_file_range_linux.icpp"
 #include "fs_copy_file_range_linux.icpp"
 #else
-#warning "using fs_copy_file_range_unsupported.icpp"
+#pragma message "using fs_copy_file_range_unsupported.icpp"
 #include "fs_copy_file_range_unsupported.icpp"
 #endif
