@@ -18,6 +18,11 @@
 
 #pragma once
 
+#include "fs_fchmodat.hpp"
+
+#include "fs_path.hpp"
+#include "to_neg_errno.hpp"
+
 #include <string>
 
 #include <fcntl.h>
@@ -34,7 +39,14 @@ namespace fs
            const mode_t  mode_,
            const int     flags_)
   {
-    return ::fchmodat(dirfd_,pathname_,mode_,flags_);
+    int rv;
+
+    rv = ::fchmodat(dirfd_,
+                    pathname_,
+                    mode_,
+                    flags_);
+
+    return ::to_neg_errno(rv);
   }
 
   static
@@ -45,6 +57,23 @@ namespace fs
            const mode_t       mode_,
            const int          flags_)
   {
-    return fs::fchmodat(dirfd_,pathname_.c_str(),mode_,flags_);
+    return fs::fchmodat(dirfd_,
+                        pathname_.c_str(),
+                        mode_,
+                        flags_);
+  }
+
+  static
+  inline
+  int
+  fchmodat(const int       dirfd_,
+           const fs::path &pathname_,
+           const mode_t    mode_,
+           const int       flags_)
+  {
+    return fs::fchmodat(dirfd_,
+                        pathname_.c_str(),
+                        mode_,
+                        flags_);
   }
 }
