@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include "errno.hpp"
+#include "to_neg_errno.hpp"
 #include "fs_fstat.hpp"
 
 #include <sys/stat.h>
@@ -35,7 +35,11 @@ namespace fs
          const uid_t uid_,
          const gid_t gid_)
   {
-    return ::fchown(fd_,uid_,gid_);
+    int rv;
+
+    rv = ::fchown(fd_,uid_,gid_);
+
+    return ::to_neg_errno(rv);
   }
 
   static
@@ -56,19 +60,19 @@ namespace fs
     int rv;
 
     rv = fs::fchown(fd_,st_);
-    if(rv == -1)
+    if(rv < 0)
       {
-        int error;
+        int err;
         struct stat tmpst;
 
-        error = errno;
+        err = rv;
         rv = fs::fstat(fd_,&tmpst);
-        if(rv == -1)
-          return -1;
+        if(rv < 0)
+          return err;
 
         if((st_.st_uid != tmpst.st_uid) ||
            (st_.st_gid != tmpst.st_gid))
-          return (errno=error,-1);
+          return err;
       }
 
     return 0;
