@@ -30,8 +30,8 @@ namespace fs
     struct stat st;
 
     rv = fs::fstat(fd_,&st);
-    if(rv == -1)
-      return -1;
+    if(rv < 0)
+      return rv;
 
     return st.st_size;
   }
