@@ -18,7 +18,8 @@
 
 #pragma once
 
-#include <stdint.h>
+#include <cstdint>
+
 
 namespace fs
 {
