@@ -26,8 +26,8 @@
 namespace fs
 {
   int
-  findonfs(const Branches::CPtr &branches,
-           const std::string    &fusepath,
-           const int             fd,
-           std::string          *basepath);
+  findonfs(const Branches::Ptr &branches,
+           const std::string   &fusepath,
+           const int            fd,
+           std::string         *basepath);
 }
