@@ -19,6 +19,8 @@
 
 #pragma once
 
+#include "to_neg_errno.hpp"
+
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -32,6 +34,10 @@ namespace fs
   fstat(const int    fd_,
         struct stat *st_)
   {
-    return ::fstat(fd_,st_);
+    int rv;
+
+    rv = ::fstat(fd_,st_);
+
+    return ::to_neg_errno(rv);
   }
 }
