@@ -18,10 +18,10 @@
 
 #pragma once
 
-#include <sys/types.h>
+#include "fs_path.hpp"
+#include "to_neg_errno.hpp"
+
 #include <sys/stat.h>
-#include <unistd.h>
-#include <fcntl.h>
 
 
 namespace fs
@@ -34,10 +34,28 @@ namespace fs
           struct stat *statbuf_,
           const int    flags_)
   {
-    return ::fstatat(dirfd_,
-                     pathname_,
-                     statbuf_,
-                     flags_);
+    int rv;
+
+    rv = ::fstatat(dirfd_,
+                   pathname_,
+                   statbuf_,
+                   flags_);
+
+    return ::to_neg_errno(rv);
+  }
+
+  static
+  inline
+  int
+  fstatat(const int       dirfd_,
+          const fs::path &pathname_,
+          struct stat    *statbuf_,
+          const int       flags_)
+  {
+    return fs::fstatat(dirfd_,
+                       pathname_.c_str(),
+                       statbuf_,
+                       flags_);
   }
 
   static
@@ -52,4 +70,17 @@ namespace fs
                        statbuf_,
                        AT_SYMLINK_NOFOLLOW);
   }
+
+  static
+  inline
+  int
+  fstatat_nofollow(const int       dirfd_,
+                   const fs::path &pathname_,
+                   struct stat    *statbuf_)
+  {
+    return fs::fstatat(dirfd_,
+                       pathname_,
+                       statbuf_,
+                       AT_SYMLINK_NOFOLLOW);
+  }
 }
