@@ -16,7 +16,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include "errno.hpp"
+#include "to_neg_errno.hpp"
+
+#include <sys/types.h>
 
 #if defined __linux__
 #include <unistd.h>
@@ -26,15 +28,19 @@
 
 namespace fs
 {
-  int
-  getdents_64(unsigned int  fd_,
-              void         *dirp_,
-              unsigned int  count_)
+  ssize_t
+  getdents64(const int     fd_,
+             void         *dirp_,
+             const size_t  count_)
   {
 #if defined SYS_getdents64
-    return ::syscall(SYS_getdents64,fd_,dirp_,count_);
+    ssize_t rv;
+
+    rv = ::syscall(SYS_getdents64,fd_,dirp_,count_);
+
+    return ::to_neg_errno(rv);
 #else
-    return (errno=ENOTSUP,-1);
+    return -ENOTSUP;
 #endif
   }
 }
