@@ -18,6 +18,8 @@
 
 #pragma once
 
+#include "fuse_kernel.h"
+
 #include <cstdint>
 #include <string>
 
@@ -28,27 +30,19 @@ namespace fs
 {
   namespace inode
   {
-    static const uint64_t MAGIC = 0x7472617065786974;
-
     int set_algo(const std::string &s);
     std::string get_algo(void);
 
-    uint64_t calc(const char     *fusepath,
-                  const uint64_t  fusepath_len,
-                  const mode_t    mode,
-                  const dev_t     dev,
-                  const ino_t     ino);
-    uint64_t calc(std::string const &fusepath,
-                  mode_t const       mode,
-                  dev_t const        dev,
-                  ino_t              ino);
-    void calc(const char     *fusepath,
-              const uint64_t  fusepath_len,
-              struct stat    *st);
-    void calc(const char  *fusepath,
-              struct stat *st);
-    void calc(const std::string &fusepath,
-              struct stat       *st);
+    uint64_t calc(const std::string &basepath,
+                  const std::string &fusepath,
+                  const mode_t           mode,
+                  const ino_t            ino);
 
+    void calc(const std::string &basepath,
+              const std::string &fusepath,
+              struct stat            *st);
+    void calc(const std::string &basepath,
+              const std::string &fusepath,
+              struct fuse_statx *st);
   }
 }
