@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include "errno.hpp"
+#include "to_neg_errno.hpp"
 #include "xattr.hpp"
 
 #include <string>
@@ -30,21 +30,25 @@ namespace fs
 {
   static
   inline
-  int
+  ssize_t
   llistxattr(const char   *path_,
              char         *list_,
              const size_t  size_)
   {
 #ifdef USE_XATTR
-    return ::llistxattr(path_,list_,size_);
+    ssize_t rv;
+
+    rv = ::llistxattr(path_,list_,size_);
+
+    return ::to_neg_errno(rv);
 #else
-    return (errno=ENOTSUP,-1);
+    return -ENOTSUP;
 #endif
   }
 
   static
   inline
-  int
+  ssize_t
   llistxattr(const std::string &path_,
              char              *list_,
              const size_t       size_)
