@@ -18,7 +18,9 @@
 
 #pragma once
 
-#include "ghc/filesystem.hpp"
+#include "to_neg_errno.hpp"
+
+#include "fs_path.hpp"
 
 #include <string>
 
@@ -34,7 +36,12 @@ namespace fs
   mkdir(const char   *path_,
         const mode_t  mode_)
   {
-    return ::mkdir(path_,mode_);
+    int rv;
+
+    rv = ::mkdir(path_,
+                 mode_);
+
+    return ::to_neg_errno(rv);
   }
 
   static
@@ -43,15 +50,17 @@ namespace fs
   mkdir(const std::string &path_,
         const mode_t       mode_)
   {
-    return fs::mkdir(path_.c_str(),mode_);
+    return fs::mkdir(path_.c_str(),
+                     mode_);
   }
 
   static
   inline
   int
-  mkdir(const ghc::filesystem::path &path_,
-        const mode_t                 mode_)
+  mkdir(const fs::path &path_,
+        const mode_t    mode_)
   {
-    return fs::mkdir(path_.c_str(),mode_);
+    return fs::mkdir(path_.c_str(),
+                     mode_);
   }
 }
