@@ -18,6 +18,8 @@
 
 #pragma once
 
+#include "to_neg_errno.hpp"
+
 #include <string>
 
 #include <unistd.h>
@@ -31,7 +33,11 @@ namespace fs
   symlink(const char *target_,
           const char *linkpath_)
   {
-    return ::symlink(target_,linkpath_);
+    int rv;
+
+    rv = ::symlink(target_,linkpath_);
+
+    return ::to_neg_errno(rv);
   }
 
   static
@@ -40,7 +46,8 @@ namespace fs
   symlink(const std::string &target_,
           const std::string &linkpath_)
   {
-    return ::symlink(target_.c_str(),linkpath_.c_str());
+    return fs::symlink(target_.c_str(),
+                       linkpath_.c_str());
   }
 
   static
@@ -49,6 +56,7 @@ namespace fs
   symlink(const char        *target_,
           const std::string &linkpath_)
   {
-    return ::symlink(target_,linkpath_.c_str());
+    return fs::symlink(target_,
+                       linkpath_.c_str());
   }
 }
