@@ -1,6 +1,5 @@
 /*
   ISC License
-
   Copyright (c) 2023, Antonio SJ Musumeci <trapexit@spawn.link>
 
   Permission to use, copy, modify, and/or distribute this software for any
@@ -18,10 +17,7 @@
 
 #pragma once
 
-#include "ghc/filesystem.hpp"
-
-#include "fs_pathvector.hpp"
-#include "fs_stat.hpp"
+#include "fs_path.hpp"
 
 #include <chrono>
 #include <vector>
@@ -29,8 +25,8 @@
 
 namespace fs
 {
-  void
-  wait_for_mount(const fs::Path                  &srcpath,
-                 const fs::PathVector            &tgtpaths,
+  int
+  wait_for_mount(const fs::path                  &srcpath,
+                 const std::vector<fs::path>     &tgtpaths,
                  const std::chrono::milliseconds &timeout);
 }
