@@ -16,24 +16,21 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "fuse_bmap.hpp"
+
 #include "errno.hpp"
 
-#include <cstdint>
 
-#include <stddef.h>
-
-
-namespace FUSE
+int
+FUSE::bmap(const fuse_req_ctx_t *ctx_,
+           const char           *fusepath_,
+           size_t                blocksize_,
+           uint64_t             *idx_)
 {
-  int
-  bmap(const char *fusepath_,
-       size_t      blocksize_,
-       uint64_t   *idx_)
-  {
-    (void)fusepath_;
-    (void)blocksize_;
-    (void)idx_;
+  (void)ctx_;
+  (void)fusepath_;
+  (void)blocksize_;
+  (void)idx_;
 
-    return -ENOSYS;
-  }
+  return -ENOSYS;
 }
