@@ -16,14 +16,27 @@
 
 #pragma once
 
+#include "fuse.h"
+
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+#ifndef _FILE_OFFSET_BITS
+#define _FILE_OFFSET_BITS 64
+#endif
+
+#include "fuse.h"
+
+#include <unistd.h>
 
 namespace FUSE
 {
   ssize_t
-  copy_file_range(const fuse_file_info_t *ffi_in,
+  copy_file_range(const fuse_req_ctx_t   *ctx_,
+                  const fuse_file_info_t *ffi_in,
                   off_t                   offset_in,
                   const fuse_file_info_t *ffi_out,
                   off_t                   offset_out,
-                  size_t                  size,
-                  int                     flags);
+                  const size_t            size,
+                  const unsigned int      flags);
 }
