@@ -24,7 +24,8 @@
 namespace FUSE
 {
   int
-  create(const char       *fusepath,
-         mode_t            mode,
-         fuse_file_info_t *ffi);
+  create(const fuse_req_ctx_t *ctx,
+         const char           *fusepath,
+         mode_t                mode,
+         fuse_file_info_t     *ffi);
 }
