@@ -14,11 +14,10 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-namespace FUSE
+#include "fuse_destroy.hpp"
+
+void
+FUSE::destroy(void)
 {
-  void
-  destroy(void)
-  {
 
-  }
 }
