@@ -14,38 +14,49 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "fuse_fchmod.hpp"
+
 #include "errno.hpp"
 #include "fileinfo.hpp"
 #include "fs_fchmod.hpp"
+#include "state.hpp"
 
 #include "fuse.h"
 
 
-namespace l
+static
+int
+_fchmod(const int    fd_,
+        const mode_t mode_)
 {
-  static
-  int
-  fchmod(const int    fd_,
-         const mode_t mode_)
-  {
-    int rv;
+  int rv;
 
-    rv = fs::fchmod(fd_,mode_);
-    if(rv == -1)
-      return -errno;
+  rv = fs::fchmod(fd_,mode_);
 
-    return rv;
-  }
+  return rv;
 }
 
-namespace FUSE
+int
+FUSE::fchmod(const fuse_req_ctx_t *ctx_,
+             const uint64_t        fh_,
+             const mode_t          mode_)
 {
-  int
-  fchmod(const fuse_file_info_t *ffi_,
-         const mode_t            mode_)
-  {
-    FileInfo *fi = reinterpret_cast<FileInfo*>(ffi_->fh);
+  uint64_t fh;
 
-    return l::fchmod(fi->fd,mode_);
-  }
+  fh = fh_;
+  if(fh == 0)
+    {
+      state.open_files.cvisit(ctx_->nodeid,
+                              [&](auto &val_)
+                              {
+                                fh = val_.second.fi->to_fh();
+                              });
+    }
+
+  if(fh == 0)
+    return -ENOENT;
+
+  FileInfo *fi = FileInfo::from_fh(fh);
+
+  return ::_fchmod(fi->fd,mode_);
 }
