@@ -14,36 +14,49 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "fuse_flock.hpp"
+
 #include "errno.hpp"
 #include "fileinfo.hpp"
 #include "fs_flock.hpp"
+#include "state.hpp"
 
 #include "fuse.h"
 
 
-namespace l
+static
+int
+_flock(const int fd_,
+       const int operation_)
 {
-  static
-  int
-  flock(const int fd_,
-        const int operation_)
-  {
-    int rv;
+  int rv;
 
-    rv = fs::flock(fd_,operation_);
+  rv = fs::flock(fd_,operation_);
 
-    return ((rv == -1) ? -errno : 0);
-  }
+  return rv;
 }
 
-namespace FUSE
+int
+FUSE::flock(const fuse_req_ctx_t   *ctx_,
+            const fuse_file_info_t *ffi_,
+            int                     op_)
 {
-  int
-  flock(const fuse_file_info_t *ffi_,
-        int                     op_)
-  {
-    FileInfo* fi = reinterpret_cast<FileInfo*>(ffi_->fh);
+  uint64_t fh;
 
-    return l::flock(fi->fd,op_);
-  }
+  fh = ffi_->fh;
+  if(fh == 0)
+    {
+      state.open_files.cvisit(ctx_->nodeid,
+                              [&](const auto &val_)
+                              {
+                                fh = val_.second.fi->to_fh();
+                              });
+    }
+
+  if(fh == 0)
+    return -ENOENT;
+
+  FileInfo* fi = FileInfo::from_fh(fh);
+
+  return ::_flock(fi->fd,op_);
 }
