@@ -14,36 +14,46 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "fuse_ftruncate.hpp"
+
 #include "errno.hpp"
 #include "fileinfo.hpp"
 #include "fs_ftruncate.hpp"
+#include "state.hpp"
 
 #include "fuse.h"
 
 
-namespace l
+static
+int
+_ftruncate(const int   fd_,
+           const off_t size_)
 {
-  static
-  int
-  ftruncate(const int   fd_,
-            const off_t size_)
-  {
-    int rv;
+  int rv;
 
-    rv = fs::ftruncate(fd_,size_);
+  rv = fs::ftruncate(fd_,size_);
 
-    return ((rv == -1) ? -errno : 0);
-  }
+  return rv;
 }
 
-namespace FUSE
+int
+FUSE::ftruncate(const fuse_req_ctx_t *ctx_,
+                const uint64_t        fh_,
+                off_t                 size_)
 {
-  int
-  ftruncate(const fuse_file_info_t *ffi_,
-            off_t                   size_)
-  {
-    FileInfo *fi = reinterpret_cast<FileInfo*>(ffi_->fh);
+  uint64_t fh;
 
-    return l::ftruncate(fi->fd,size_);
-  }
+  fh = fh_;
+  if(fh == 0)
+    {
+      state.open_files.cvisit(ctx_->nodeid,
+                              [&](auto &val_)
+                              {
+                                fh = val_.second.fi->to_fh();
+                              });
+    }
+
+  FileInfo *fi = FileInfo::from_fh(fh);
+
+  return ::_ftruncate(fi->fd,size_);
 }
