@@ -25,6 +25,7 @@
 namespace FUSE
 {
   int
-  ftruncate(const fuse_file_info_t *ffi,
-            off_t                   size);
+  ftruncate(const fuse_req_ctx_t *ctx,
+            const uint64_t        fh,
+            off_t                 size);
 }
