@@ -14,40 +14,48 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "fuse_futimens.hpp"
+
 #include "errno.hpp"
 #include "fileinfo.hpp"
 #include "fs_futimens.hpp"
+#include "state.hpp"
 
 #include "fuse.h"
 
 #include <sys/stat.h>
 
 
-namespace l
+static
+int
+_futimens(const int             fd_,
+          const struct timespec ts_[2])
 {
-  static
-  int
-  futimens(const int             fd_,
-           const struct timespec ts_[2])
-  {
-    int rv;
+  int rv;
 
-    rv = fs::futimens(fd_,ts_);
-    if(rv == -1)
-      return -errno;
+  rv = fs::futimens(fd_,ts_);
 
-    return rv;
-  }
+  return rv;
 }
 
-namespace FUSE
+int
+FUSE::futimens(const fuse_req_ctx_t  *ctx_,
+               const uint64_t         fh_,
+               const struct timespec  ts_[2])
 {
-  int
-  futimens(const fuse_file_info_t *ffi_,
-           const struct timespec   ts_[2])
-  {
-    FileInfo *fi = reinterpret_cast<FileInfo*>(ffi_->fh);
+  uint64_t fh;
 
-    return l::futimens(fi->fd,ts_);
-  }
+  fh = fh_;
+  if(fh == 0)
+    {
+      state.open_files.cvisit(ctx_->nodeid,
+                              [&](const auto &val_)
+                              {
+                                fh = val_.second.fi->to_fh();
+                              });
+    }
+
+  FileInfo *fi = FileInfo::from_fh(fh);
+
+  return ::_futimens(fi->fd,ts_);
 }
