@@ -16,6 +16,10 @@
 
 #pragma once
 
+#include "fuse.h"
+
+#include "fs_path.hpp"
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -24,7 +28,20 @@
 namespace FUSE
 {
   int
-  getattr(const char      *fusepath,
+  getattr(const fuse_req_ctx_t *ctx,
+          const char           *fusepath,
+          struct stat          *buf,
+          fuse_timeouts_t      *timeout);
+
+  int
+  getattr(const fuse_req_ctx_t *ctx,
+          const fs::path       &fusepath,
+          struct stat          *buf,
+          fuse_timeouts_t      *timeout);
+
+  int
+  getattr(const fs::path  &fusepath,
           struct stat     *buf,
           fuse_timeouts_t *timeout);
+
 }
