@@ -18,6 +18,8 @@
 
 #include "fuse.h"
 
+#include <string_view>
+
 
 namespace FUSE
 {
@@ -28,7 +30,8 @@ namespace FUSE
     virtual ~ReadDirBase() {};
 
   public:
-    virtual int operator()(fuse_file_info_t const *ffi,
+    virtual int operator()(const fuse_req_ctx_t   *ctx,
+                           const fuse_file_info_t *ffi,
                            fuse_dirents_t         *buf) = 0;
   };
 }
