@@ -29,7 +29,8 @@ namespace FUSE
     ReadDirSeq() {}
     ~ReadDirSeq() {}
 
-    int operator()(fuse_file_info_t const *ffi,
+    int operator()(const fuse_req_ctx_t   *ctx,
+                   const fuse_file_info_t *ffi,
                    fuse_dirents_t         *buf);
   };
 }
