@@ -16,13 +16,18 @@
 
 #pragma once
 
+#include <cstddef>
+
+#include "fuse_req_ctx.h"
+
 
 namespace FUSE
 {
   int
-  setxattr(const char *fusepath,
-           const char *attrname,
-           const char *attrval,
-           size_t      attrvalize,
-           int         flags);
+  setxattr(const fuse_req_ctx_t *ctx,
+           const char           *fusepath,
+           const char           *attrname,
+           const char           *attrval,
+           size_t                attrvalize,
+           int                   flags);
 }
