@@ -24,9 +24,10 @@
 
 
 int
-FUSE::tmpfile(const char       *fusepath_,
-              mode_t            mode_,
-              fuse_file_info_t *ffi_)
+FUSE::tmpfile(const fuse_req_ctx_t *ctx_,
+              const char           *fusepath_,
+              mode_t                mode_,
+              fuse_file_info_t     *ffi_)
 {
   return -ENOSYS;
 }
