@@ -16,11 +16,12 @@
 
 #pragma once
 
+#include <cstdint>
 #include <string>
 
-#include <stdint.h>
 #include <sys/statvfs.h>
 
+
 namespace StatVFS
 {
   static
