@@ -16,43 +16,46 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "to_string.hpp"
+
+#include "fmt/core.h"
+
 #include <cstdint>
 #include <string>
 
-#include <inttypes.h>
-#include <stdio.h>
 
-namespace str
+std::string
+str::to(const bool bool_)
 {
-  std::string
-  to(const bool bool_)
-  {
-    return (bool_ ? "true" : "false");
-  }
+  return (bool_ ? "true" : "false");
+}
 
-  std::string
-  to(const int int_)
-  {
-    char buf[24];
+std::string
+str::to(const int int_)
+{
+  return fmt::format("{}",int_);
+}
 
-    sprintf(buf,"%d",int_);
+std::string
+str::to(const uint64_t uint64_)
+{
+  return fmt::format("{}",uint64_);
+}
 
-    return buf;
-  }
+std::string
+str::to(const int64_t int64_)
+{
+  return fmt::format("{}",int64_);
+}
 
-  std::string
-  to(const uint64_t uint64_)
-  {
-    char buf[64];
+std::string
+str::to(const std::string &s_)
+{
+  return s_;
+}
 
-    sprintf(buf,"%llu",(unsigned long long)uint64_);
-
-    return buf;
-  }
-
-  std::string
-  to(const std::string &s_)
-  {
-    return s_;
-  }
+std::string
+str::to(const fs::path &path_)
+{
+  return path_.string();
 }
