@@ -18,7 +18,10 @@
 
 #pragma once
 
+#include "fs_path.hpp"
+
 #include <cstdint>
+#include <filesystem>
 #include <string>
 
 
@@ -27,5 +30,7 @@ namespace str
   std::string to(const bool);
   std::string to(const int);
   std::string to(const uint64_t);
+  std::string to(const int64_t);
   std::string to(const std::string&);
+  std::string to(const fs::path&);
 }
