@@ -29,7 +29,7 @@ class ToFromWrapper : public ToFromString
 {
 public:
   int
-  from_string(const std::string &s_) final
+  from_string(const std::string_view s_) final
   {
     return str::from(s_,&_data);
   }
@@ -41,11 +41,11 @@ public:
   }
 
 public:
-  ToFromWrapper<T>()
+  ToFromWrapper()
   {
   }
 
-  ToFromWrapper<T>(const T data_)
+  ToFromWrapper(const T data_)
     : _data(data_)
   {
   }
@@ -64,6 +64,13 @@ public:
     return _data;
   }
 
+  const
+  T&
+  operator*() const
+  {
+    return _data;
+  }
+
   T*
   operator->()
   {
@@ -93,9 +100,9 @@ class ROToFromWrapper : public ToFromString
 {
 public:
   int
-  from_string(const std::string &s_) final
+  from_string(const std::string_view s_) final
   {
-    return -EINVAL;
+    return -EROFS;
   }
 
   std::string
@@ -105,11 +112,11 @@ public:
   }
 
 public:
-  ROToFromWrapper<T>()
+  ROToFromWrapper()
   {
   }
 
-  ROToFromWrapper<T>(const T data_)
+  ROToFromWrapper(const T data_)
     : _data(data_)
   {
   }
