@@ -16,6 +16,8 @@
 
 #pragma once
 
+#include "fuse_req_ctx.h"
+
 #include <pthread.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -70,6 +72,12 @@ namespace ugid
       ugid_set(newuid_,newgid_);
     }
 
+    Set(const fuse_req_ctx_t *ctx_)
+      : Set(ctx_->uid,ctx_->gid)
+    {
+
+    }
+
     ~Set()
     {
       pthread_rwlock_unlock(&rwlock);
